@@ -3,7 +3,7 @@ package App::ModuleBuildTiny;
 use 5.014;
 use strict;
 use warnings;
-our $VERSION = '0.031';
+our $VERSION = '0.032';
 
 use Exporter 5.57 'import';
 our @EXPORT = qw/modulebuildtiny/;
@@ -124,8 +124,8 @@ my %actions = (
 		GetOptionsFromArray(\@arguments, \my %opts, qw/trial verbose!/) or return 2;
 		my $dist = App::ModuleBuildTiny::Dist->new(%opts);
 		die "Trial mismatch" if $opts{trial} && $dist->release_status ne 'testing';
-		$dist->checkchanges;
-		$dist->checkmeta;
+		$dist->check_changes;
+		$dist->check_meta;
 		my $name = $dist->meta->name . '-' . $dist->meta->version;
 		printf "tar czf $name.tar.gz %s\n", join ' ', $dist->files if $opts{verbose};
 		$dist->write_tarball($name);
@@ -149,11 +149,12 @@ my %actions = (
 	},
 	upload => sub {
 		my @arguments = @_;
-		GetOptionsFromArray(\@arguments, \my %opts, qw/trial config=s silent/) or return 2;
+		GetOptionsFromArray(\@arguments, \my %opts, qw/trial config=s silent tag push:s/) or return 2;
 
 		my $dist = App::ModuleBuildTiny::Dist->new;
-		$dist->checkchanges;
-		$dist->checkmeta;
+		$dist->check_changes;
+		$dist->check_meta;
+		local ($AUTHOR_TESTING, $RELEASE_TESTING) = (1, 1);
 		$dist->run(command => [ $Config{perlpath}, 'Build', 'test' ], build => 1) or return 1;
 
 		my $sure = prompt('Do you want to continue the release process? y/n', 'n');
@@ -166,6 +167,23 @@ my %actions = (
 			my $uploader = CPAN::Upload::Tiny->new_from_config_or_stdin($opts{config});
 			$uploader->upload_file($file);
 			print "Successfully uploaded $file\n" if not $opts{silent};
+
+			if ($opts{tag}) {
+				require Git::Wrapper;
+				my $git = Git::Wrapper->new('.');
+				say for $git->ls_files;
+				my $version = 'v' . $dist->version;
+				$git->tag('-m' => $version, $version);
+			}
+
+			if (defined $opts{push}) {
+				require Git::Wrapper;
+				my $git = Git::Wrapper->new('.');
+
+				my @remote = length $opts{push} ? $opts{push} : ();
+				$git->push(@remote);
+				$git->push({ tags => 1 }, @remote) if $opts{tag};
+			}
 		}
 		return 0;
 	},
@@ -213,11 +231,12 @@ my %actions = (
 	},
 	regenerate => sub {
 		my @arguments = @_;
-		GetOptionsFromArray(\@arguments, \my %opts, qw/trial bump version=s verbose dry_run|dry-run/) or return 2;
+		GetOptionsFromArray(\@arguments, \my %opts, qw/trial bump version=s verbose dry_run|dry-run commit/) or return 2;
 		my %files = map { $_ => 1 } @arguments ? @arguments : qw/Build.PL META.json META.yml MANIFEST LICENSE README/;
 
 		if ($opts{bump}) {
 			bump_versions(%opts);
+			$files{Changes}++;
 		}
 
 		my $dist = App::ModuleBuildTiny::Dist->new(%opts, regenerate => \%files);
@@ -226,6 +245,24 @@ my %actions = (
 			say "Updating $filename" if $opts{verbose};
 			write_binary($filename, $dist->get_file($filename)) if !$opts{dry_run};
 		}
+
+		if ($opts{commit}) {
+			require Git::Wrapper;
+			my $git = Git::Wrapper->new('.');
+			my @files = keys %files;
+			push @files, 'lib' if $opts{bump};
+			my $allowed = join '|', map qr{^\Q$_\E$}, @files;
+			my @modified = grep /$allowed/, $git->ls_files({ modified => 1 });
+
+			if (@modified) {
+				my @changes = $dist->get_changes;
+				my $version = 'v' . $dist->version;
+				my $message = join '', $version, "\n\n", @changes;
+				$git->commit({ m => $message }, @files);
+			} else {
+				say "No modifications to commit";
+			}
+		}
 		return 0;
 	},
 	scan => sub {
